<?php

// Conexión a la base de datos
include_once 'database.php';

// Consulta para obtener la cantidad de inscripciones por años
$query_inscripciones_por_anio = "
    SELECT YEAR(FECHA) AS Anio, COUNT(*) AS CantidadInscripciones
    FROM inscripciones
    GROUP BY YEAR(FECHA)
    ORDER BY Anio;
";

// Ejecutar la consulta
$resultado_inscripciones_por_anio = mysqli_query($conexion, $query_inscripciones_por_anio);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_inscripciones_por_anio) {
    die("Error al obtener las inscripciones por año: " . mysqli_error($conexion));
}

// Consulta para obtener la cantidad de inscripciones por mes
$query_inscripciones_por_mes = "
    SELECT YEAR(FECHA) AS Anio, MONTH(FECHA) AS Mes, COUNT(*) AS CantidadInscripciones
    FROM inscripciones
    GROUP BY YEAR(FECHA), MONTH(FECHA)
    ORDER BY Anio, Mes;
";

// Ejecutar la consulta
$resultado_inscripciones_por_mes = mysqli_query($conexion, $query_inscripciones_por_mes);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_inscripciones_por_mes) {
    die("Error al obtener las inscripciones por mes: " . mysqli_error($conexion));
}

// Consulta para obtener el año de mayor inscripciones
$query_anio_max_inscripciones = "
    SELECT YEAR(FECHA) AS Anio, COUNT(*) AS CantidadInscripciones
    FROM inscripciones
    GROUP BY YEAR(FECHA)
    ORDER BY CantidadInscripciones DESC
    LIMIT 1;
";

// Ejecutar la consulta
$resultado_anio_max_inscripciones = mysqli_query($conexion, $query_anio_max_inscripciones);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_anio_max_inscripciones) {
    die("Error al obtener el año de mayor inscripciones: " . mysqli_error($conexion));
}

// Obtener el resultado de la consulta
$fila_anio_max_inscripciones = mysqli_fetch_assoc($resultado_anio_max_inscripciones);
$anio_max_inscripciones = $fila_anio_max_inscripciones['Anio'];

// Consulta para obtener el año de menor inscripciones
$query_anio_min_inscripciones = "
    SELECT YEAR(FECHA) AS Anio, COUNT(*) AS CantidadInscripciones
    FROM inscripciones
    GROUP BY YEAR(FECHA)
    ORDER BY CantidadInscripciones ASC
    LIMIT 1;
";

// Ejecutar la consulta
$resultado_anio_min_inscripciones = mysqli_query($conexion, $query_anio_min_inscripciones);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_anio_min_inscripciones) {
    die("Error al obtener el año de menor inscripciones: " . mysqli_error($conexion));
}

// Obtener el resultado de la consulta
$fila_anio_min_inscripciones = mysqli_fetch_assoc($resultado_anio_min_inscripciones);
$anio_min_inscripciones = $fila_anio_min_inscripciones['Anio'];

// Consulta para obtener el mes de mayor inscripción en cada año
$query_mes_max_inscripciones = "
    SELECT YEAR(FECHA) AS Anio, MONTH(FECHA) AS Mes, COUNT(*) AS CantidadInscripciones
    FROM inscripciones
    GROUP BY YEAR(FECHA), MONTH(FECHA)
    ORDER BY Anio, CantidadInscripciones DESC;
";

// Ejecutar la consulta
$resultado_mes_max_inscripciones = mysqli_query($conexion, $query_mes_max_inscripciones);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_mes_max_inscripciones) {
    die("Error al obtener el mes de mayor inscripción en cada año: " . mysqli_error($conexion));
}

// Consulta para obtener el mes de menor inscripción en cada año
$query_mes_min_inscripciones = "
    SELECT YEAR(FECHA) AS Anio, MONTH(FECHA) AS Mes, COUNT(*) AS CantidadInscripciones
    FROM inscripciones
    GROUP BY YEAR(FECHA), MONTH(FECHA)
    ORDER BY Anio, CantidadInscripciones ASC;
";

// Ejecutar la consulta
$resultado_mes_min_inscripciones = mysqli_query($conexion, $query_mes_min_inscripciones);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_mes_min_inscripciones) {
    die("Error al obtener el mes de menor inscripción en cada año: " . mysqli_error($conexion));
}

// Consulta para obtener el total de personas que pagan
$query_total_pagan = "
    SELECT COUNT(*) AS TotalPagan
    FROM inscripciones
    WHERE PAGO = 'Si';
";

// Ejecutar la consulta
$resultado_total_pagan = mysqli_query($conexion, $query_total_pagan);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_total_pagan) {
    die("Error al obtener el total de personas que pagan: " . mysqli_error($conexion));
}

// Obtener el resultado de la consulta
$fila_total_pagan = mysqli_fetch_assoc($resultado_total_pagan);
$total_pagan = $fila_total_pagan['TotalPagan'];

// Consulta para obtener el total de personas que pagan cada año
$query_total_pagan_por_anio = "
    SELECT YEAR(FECHA) AS Anio, COUNT(*) AS TotalPagan
    FROM inscripciones
    WHERE PAGO = 'Si'
    GROUP BY YEAR(FECHA)
    ORDER BY Anio;
";

// Ejecutar la consulta
$resultado_total_pagan_por_anio = mysqli_query($conexion, $query_total_pagan_por_anio);

// Verificar si se ejecutó correctamente la consulta
if (!$resultado_total_pagan_por_anio) {
    die("Error al obtener el total de personas que pagan cada año: " . mysqli_error($conexion));
}

// Cerrar la conexión a la base de datos
mysqli_close($conexion);

?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Resultados de Consultas</title>
</head>
<body>
    <h1>Resultados de las consultas</h1>

    <h2>Cantidad de inscripciones por año</h2>
    <ul>
        <?php
        // Recorrer y mostrar el resultado de la consulta
        while ($fila = mysqli_fetch_assoc($resultado_inscripciones_por_anio)) {
            echo "<li>Año {$fila['Anio']}: {$fila['CantidadInscripciones']} inscripciones</li>";
        }
        ?>
    </ul>

    <h2>Cantidad de inscripciones por mes</h2>
    <ul>
        <?php
        // Recorrer y mostrar el resultado de la consulta
        while ($fila = mysqli_fetch_assoc($resultado_inscripciones_por_mes)) {
            echo "<li>Año {$fila['Anio']}, Mes {$fila['Mes']}: {$fila['CantidadInscripciones']} inscripciones</li>";
        }
        ?>
    </ul>

    <h2>Año de mayor inscripciones</h2>
    <?php
    // Mostrar el resultado de la consulta
    echo "<p>Año de mayor inscripciones: $anio_max_inscripciones</p>";
    ?>

    <h2>Año de menor inscripciones</h2>
    <?php
    // Mostrar el resultado de la consulta
    echo "<p>Año de menor inscripciones: $anio_min_inscripciones</p>";
    ?>

    <h2>Mes de mayor inscripción en cada año</h2>
    <ul>
        <?php
        // Recorrer y mostrar el resultado de la consulta
        while ($fila = mysqli_fetch_assoc($resultado_mes_max_inscripciones)) {
            echo "<li>Año {$fila['Anio']}, Mes {$fila['Mes']}: {$fila['CantidadInscripciones']} inscripciones</li>";
        }
        ?>
    </ul>

    <h2>Mes de menor inscripción en cada año</h2>
    <ul>
        <?php
        // Recorrer y mostrar el resultado de la consulta
        while ($fila = mysqli_fetch_assoc($resultado_mes_min_inscripciones)) {
            echo "<li>Año {$fila['Anio']}, Mes {$fila['Mes']}: {$fila['CantidadInscripciones']} inscripciones</li>";
        }
        ?>
    </ul>

    <h2>Total de personas que pagan</h2>
    <?php
    // Mostrar el resultado de la consulta
    echo "<p>Total de personas que pagan: $total_pagan</p>";
    ?>

    <h2>Total de personas que pagan cada año</h2>
    <ul>
        <?php
        // Recorrer y mostrar el resultado de la consulta
        while ($fila = mysqli_fetch_assoc($resultado_total_pagan_por_anio)) {
            echo "<li>Año {$fila['Anio']}: {$fila['TotalPagan']} personas pagan</li>";
        }
        ?>
    </ul>

</body>
</html>
